import java.awt.*;
import java.util.Observable;
import java.util.Observer;

import javax.swing.*;

public class View extends JFrame implements Observer {

	public JButton start = new JButton("Start");
	public JButton clear = new JButton("Clear");
	
	private JTextField firstInput 	= new JTextField(5);
	private JTextField secondInput 	= new JTextField(5);
	private JTextField result     	= new JTextField(5);
	private String[] methods 		= {"+", "-", "*", "/"};
	private JComboBox  methodBox 	= new JComboBox(methods);
	
	/**
	 * Constructor
	 * @param yacaController Controller object for MVC...
	 */
	
 public View(Controller yacaController) { 
	
	this.setTitle("YetAnotherCalculator");
	this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	
	JPanel contentAll = new JPanel();
	contentAll.setLayout(new BorderLayout());
	
	JPanel contentButtons = new JPanel();
	contentButtons.setLayout(new FlowLayout());
	
	contentButtons.add(start);
	start.setActionCommand("Start");
	start.addActionListener(yacaController);
	
	contentButtons.add(clear);
	clear.setActionCommand("Clear");
	clear.addActionListener(yacaController);
	
	contentAll.add(contentButtons, BorderLayout.SOUTH);
		
	JPanel contentInput = new JPanel(new FlowLayout());
	contentInput.add(firstInput);
	firstInput.setText("0");
	contentInput.add(methodBox);
	contentInput.add(secondInput);
	secondInput.setText("0");
	contentInput.add(new JLabel("="));
	contentInput.add(result);
	contentAll.add(contentInput, BorderLayout.CENTER);

	result.setEditable(false);
	
	this.setContentPane(contentAll);
	
	this.setLocationRelativeTo(null);
	this.pack(); 
 }

	/**
	 * Returns the first input.
	 * @return First Input as float.
	 */
 
 	public float getFirstInput() {
 		float a = 0;
 		try {			
 			a = Float.parseFloat(firstInput.getText());
		} catch (NumberFormatException e) {
			System.out.println("Ungueltiger erster Wert");
		}
 		return a;
 	}
 
 	/**
 	 * Returns the second input.
 	 * @return Second Input as float.
 	 */
 	
 	public float getSecondInput() {
 		float b = 0;
 		try {			
 			b = Float.parseFloat(secondInput.getText());
		} catch (NumberFormatException e) {
			System.out.println("Ungueltiger zweiter Wert");
		}
 		return b;
 	}
 	
 	/**
 	 * Returns the active method.
 	 * @return Active method as String.
 	 */
 	
 	public String getMethod() {
 		String method = (String)methodBox.getSelectedItem();
 		return method;
 	}
 	
 	/**
 	 * Updates the GUI based on Model's variables.
 	 */
 	
	public void update(Observable o, Object obj) {
		Model m = (Model) o;
		result.setText("" + m.getResult());
		firstInput.setText("" + m.getA());
		secondInput.setText("" + m.getB());
	}
}
